@@ -734,3 +734,16 @@ class TestFront(unittest.TestCase):
         self.assertEqual(files["new.txt"], b'hello123')
         r = MyInst().read_resource('new.txt', filesystem='my-s3')
         self.assertEqual(r, b'hello123')
+
+    def test_write_resource__dataframe__options(self):
+        """
+        Store a dataframe, passing options through to pandas to control formatting.
+        """
+        files = {}
+        class MyInst(DSLibrary):
+            def _opener(self, path: str, mode: str, **kwargs):
+                def store(strm):
+                    files[path] = strm.read()
+                return write_stream_with_read_on_close(mode, 'r', on_close=store)
+        MyInst().write_resource('f', pandas.DataFrame({"x": [1, 2], "y": [10, 20]}), format_options={"format": "csv", "sep": ";"})
+        self.assertEqual(files["f"], 'x;y\n1;10\n2;20\n')
